/**
 * Created by winber<winberxie@163.com>.
 * ComponentName Cell
 * Desc 组件描述内容
 * GroupName lm-component
 */
import React from 'react';
import PropTypes from 'prop-types';

import classNames from 'classnames';
import './index.scss';

/**
 * @description: 判断当前组件是否可以点击
 * @param {Array} children 
 * @return: string class 名字
 */
const getActiveCls = (children = []) => {
    if (!children || !Array.isArray(children)) return '';

    const index = children.length - 1;
    const child = children[index];
    const { props } = child || {};
    const { direction } = props || {};

    return direction ? 'lm-cells-item-link' : '';
}
export const CellsTitle = ({
    className,
    children,
    ...others
}) => {

    const cls = classNames({
        'lm-cells-title': true,
    }, className);

    return (
        <div className={cls} {...others}>
            {children}
        </div>
    )

};

export const Cells = ({
    className,
    children,
    ...others
}) => {

    const cls = classNames({
        'lm-cells': true,
    }, className);

    return (
        <div className={cls} {...others}>
            {children}
        </div>
    )
};

export const Label = ({
                className,
                children,
                ...others
             }) => {

    const cls = classNames({
        'lm-cell-label': true,
    }, className);

    return (
        <div className={cls} {...others}>
            {children}
        </div>
    )

};

export const Cell = ({
                className,
                children,
                Component,
                href,
                disabled = false,
                link = false,
                ...others
             }) => {

    const cls = classNames({
        'lm-cells-item': true,
        'lm-cells-border': Component || href,
        'lm-cells-item-link': !disabled && link,
        'lm-cells-disabled': disabled
    }, className);

    const renderDom = () => {
        if(Component) {
            return (
                <Component
                    className={cls}
                    {...others}
                >
                    {children}
                </Component>
            )    
        } else if(href) {
            return (
                <a 
                    href={href}
                    className={cls}
                    {...others}
                >
                    {children}
                </a>
            )
            
        } else {
            return (
                <div className={cls} {...others}>
                    {children}
                </div>
            )
        }
    }





    return renderDom()
    
};

export const CellHeader = ({
                icon,
                className,
                children,
                ...others
             }) => {

    const cls = classNames({
        'lm-cells-item-header': true,
    }, className);

    return (
        <div className={cls} {...others}>
            <img alt="" src={icon}/>
        </div>
    )

};

export const CellBody = ({
                className,
                children,
                subDesc,
                ...others
             }) => {

    const cls = classNames({
        'lm-cells-item-body': true,
    }, className);

    return (
        <div className={cls} {...others}>
            {children}
            {subDesc && <p className="lm-cells-item-sub">{subDesc}</p>}
        </div>
    )
};
export const CellFooter = ({
                className,
                children,
                direction,
                ...others
             }) => {

    const cls = classNames({
        'lm-cells-item-footer': true,
        [`lm-cells-item-icon-${direction}`]:direction
    }, className);

    return (
        <div className={cls} {...others}>
            {children}
        </div>
    )
};

CellFooter.propTypes = {
    direction: PropTypes.string
};